@@ -17,8 +17,6 @@
    02110-1301, USA
 */
 
-#define KDE_NO_COMPAT
-
 #ifndef KSIRK_COUNTRY_H
 #define KSIRK_COUNTRY_H
 
@@ -54,10 +52,8 @@ class GameAutomaton;
  * Also, it stores pointers to the objects that represent  its owner and the
  * sprites of its flag and its armies.
  */
-class Country : QObject
+class Country
 {
-  Q_OBJECT 
-
 public:
   /**
     * Constructor
@@ -79,7 +75,7 @@ public:
       const QPointF& infantryPoint);
 
   /** Default destructor */
-  ~Country() override;
+  ~Country();
 
   GameAutomaton* automaton() {return m_automaton;}
 
